@@ -243,7 +243,8 @@ class PostCreate(CreateView):
         form.instance.date_created = datetime.now()
         form.instance.topic = get_object_or_404(mymodels.Topic, slug=self.kwargs['slug'], closed=0)
         """ DEACTIVED: Email subscribers when a new comment is posted """
-        #for subscriber in form.instance.topic.subscribers.all():
+        for subscriber in form.instance.topic.subscribers.all():
+            utils.mysendmail(subscriber.email, 'newpost', [form.instance.topic.title, form.instance.topic.slug])
         #    subject =  _('[%s] New post in a thread you\'re subscribed') % (conf.SITE_TITLE)
         #    from_email = conf.DEFAULT_FROM_EMAIL
         #    to = subscriber.email
@@ -333,6 +334,13 @@ class PostDelete(DeleteView):
 
 
 
+def PostReportInnapropiate(request, topicslug, id):
+
+    utils.mysendmail('r0sk10@gmail.com', 'inappropiate', [topicslug, id])
+    return HttpResponseRedirect(request.META.get('HTTP_REFERER', '/'))
+
+
+
 class UserProfile(UpdateView):
 
     """
